@@ -1,4 +1,4 @@
-# Copyright 2019 Juan Luis Gamella Martin
+# Copyright 2021 Juan L Gamella
 
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -89,10 +89,13 @@ class NormalDistributionTests(unittest.TestCase):
         self.assertTrue(dist_a.equal(dist_b))
         # Conditioning 2
         dist_a = dist.conditional(0, [], [])
-        dist_b = dist.conditional(0, [], [1, 2])
+        try:
+            dist.conditional(0, [], [1, 2])
+            self.fail("Exception should have been raised")
+        except ValueError as e:
+            print("OK:",e)
         dist_c = dist.marginal(0)
-        self.assertTrue(dist_a.equal(dist_b))
-        self.assertTrue(dist_b.equal(dist_c))
+        self.assertTrue(dist_a.equal(dist_c))
         
     def test_marginalization(self):
         # Test marginalization logic
@@ -110,6 +113,15 @@ class NormalDistributionTests(unittest.TestCase):
         self.assertTrue((marginal.mean == np.array([1, 3])).all())
         self.assertTrue((marginal.covariance == np.array([[11, 13], [31, 33]])).all())
 
+    def test_regression_arguments(self):
+        p = 5
+        covariance = np.eye(p)
+        mean = np.random.uniform(size=p)
+        joint = NormalDistribution(mean, covariance)
+        # Test can call with regressors as np.array (see issue #3)
+        joint.regress(0, [1,2])
+        joint.regress(0, np.array([1,2]))
+        
     def test_conditioning_1(self):
         # Test conditioning
         covariance = np.eye(3)
@@ -223,7 +235,7 @@ class NormalDistributionTests(unittest.TestCase):
         # the MSE
         joint.mean = np.random.uniform(size=p)
         self.run_mse_tests(joint, tests)
-
+        
     def regression_properties_test(self, W, parents, markov_blankets):
         # Test basic properties of the regression coefficients.
         # PRE: Assumed [1..p] is a valid causal ordering
